<?php

final class InitproKassa_AdminSettings
{
    private $options = array(
        'initprokassa_server_url' => 'string',
        'initprokassa_shop_id' => 'string',
        'initprokassa_secret_key' => 'string',
        'initprokassa_should_print' => 'bool',
        'initprokassa_queue_id' => 'string',
        'initprokassa_vat' => 'string',
        'initprokassa_vat_delivery' => 'string',
        'initprokassa_calculation_subject' => 'string',
        'initprokassa_calculation_subject_delivery' => 'string',
        'initprokassa_payment_methods' => 'string_array',
        'initprokassa_tax_system' => 'integer',
        'initprokassa_fiscalize_prepayment' => 'string',
        'initprokassa_fiscalize_full_payment' => 'string',
        'initprokassa_fiscalize_single_receipt_full_payment' => 'string',
        'initprokassa_fiscalize_refund' => 'string'
    );

    public function out()
    {
        $inputData = [];
        $errors = [];

        if (!empty($_POST)) {
            $inputData = $_POST;
            [$inputData, $errors] = $this->validate($inputData);

            if (count($errors) == 0) {
                self::save($inputData);
            }
        }

        include(INITPROKASSA_ABSPATH_VIEWS . 'html-admin-settings.php');
    }

    private function save($inputData)
    {
        foreach ($this->options as $key => $type) {
            $value = $inputData[$key];

            if ($type == 'string') {
                update_option($key, $value);
            } else if ($type == 'bool') {
                update_option($key, $value === "1" ? "1" : "0");
            } else if ($type == 'integer') {
                update_option($key, intval($value));
            } else if ($type == 'string_array') {
                update_option($key, json_encode($value));
            }
        }
    }

    private function validate($params)
    {
        $errors = [];

        $fiscalizeParams = [
            'initprokassa_fiscalize_prepayment',
            'initprokassa_fiscalize_full_payment',
            'initprokassa_fiscalize_single_receipt_full_payment',
            'initprokassa_fiscalize_refund',
        ];

        foreach ($params as $key => $value) {
            if (is_string($value)) {
                $value = trim($value);
            }

            if (
                !in_array($key, $fiscalizeParams)
                && empty($value)
                && $value !== 0
                && $value !== '0'
            ) {
                $errors[$key] = 'Обязательное поле';
            }
        }

        if (
            $params['initprokassa_fiscalize_prepayment'] !== 'no'
            && $params['initprokassa_fiscalize_full_payment'] === 'no'
        ) {
            $errors['initprokassa_fiscalize_full_payment'] = 'Обязательное, если выбрано значение для поля "Печать чека по предоплате"';
        }

        if (
            $params['initprokassa_fiscalize_prepayment'] === 'no'
            && $params['initprokassa_fiscalize_full_payment'] !== 'no'
        ) {
            $errors['initprokassa_fiscalize_prepayment'] = 'Обязательное, если выбрано значение для поля "Печать чека полного расчета(использование двух чеков)"';
        }

        if (
            $params['initprokassa_fiscalize_prepayment'] === 'no'
            && $params['initprokassa_fiscalize_full_payment'] === 'no'
            && $params['initprokassa_fiscalize_single_receipt_full_payment'] === 'no'
        ) {
            $errors['initprokassa_fiscalize_prepayment'] = 'Выберите один из сценариев';
            $errors['initprokassa_fiscalize_full_payment'] = 'Выберите один из сценариев';
            $errors['initprokassa_fiscalize_single_receipt_full_payment'] = 'Выберите один из сценариев';
        }

        if ($params['initprokassa_fiscalize_refund'] === 'no') {
            $errors['initprokassa_fiscalize_refund'] = 'Обязательное поле';
        }

        for ($i = 0; $i < count($fiscalizeParams); $i++) {
            for ($j = $i + 1; $j < count($fiscalizeParams); $j++) {
                if (
                    $params[$fiscalizeParams[$i]] === $params[$fiscalizeParams[$j]]
                    && $params[$fiscalizeParams[$i]] !== 'no'
                ) {
                    if (empty($errors[$fiscalizeParams[$i]]) && empty($errors[$fiscalizeParams[$j]])) {
                        $errors[$fiscalizeParams[$i]] = $errors[$fiscalizeParams[$j]] = 'Выбраны одинаковые статусы для разных настроек. Статусы должны быть уникальными для каждого из вариантов печати чеков.';
                    }
                }
            }
        }

        return [$params, $errors];
    }
}
