<?php

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class InitproKassa_ReportsList extends WP_List_Table {

    public static $table_name;

    public function __construct()
    {
        parent::__construct(array(
            'singular' => 'initprokassa_reports',
            'plural'   => 'initprokassa_reports',
            'ajax'     => false
        ));

        global $wpdb;
        self::$table_name = $wpdb->prefix . InitproKassa_Report::REPORT_TABLE_NAME;
    }

    public static function get_reports_data($per_page=5, $page_number=1)
    {
        global $wpdb;

        $sql = "SELECT * FROM " . self::$table_name;

        if (!empty($_REQUEST['orderby']) ) {
            $sql .= ' ORDER BY ' . esc_sql($_REQUEST['orderby']);
            $sql .= !empty($_REQUEST['order']) ? ' ' . esc_sql($_REQUEST['order']) : ' ASC';
        }

        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ($page_number - 1) * $per_page;


        $result = $wpdb->get_results($sql, 'ARRAY_A');

        return $result;
    }

    public static function record_count() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM " . self::$table_name;

        return $wpdb->get_var($sql);
    }

    public function no_items() {
        echo '<div align="center">Список пуст</div>';
    }

    public function column_default($item, $column_name) {
        switch ( $column_name ) {
            case 'report_id':
            case 'order_id':
                return $item[$column_name];
            case 'status':
                $statuses = array(
                     'new' => "Новая",
                     'error' => "Ошибка",
                     'done' => "Выполнена"
                );
                return $statuses[$item[$column_name]];
            case 'operation_type':
                $types = [
                    'sell' => 'Продажа',
                    'refund' => 'Возврат'
                ];
                return $types[$item[$column_name]];
                break;
            case 'created_at':
            case 'updated_at':
            case 'report_data':
            case 'error':
                return $item[$column_name];
            default:
                return print_r($item, true);
        }
    }

    function get_columns() {
        $columns = array(
            'report_id' => "#",
            'created_at' => "Задача создана",
            'order_id' => "Номер заказа",
            'status' => "Статус",
            'operation_type' => "Тип операции",
            'updated_at' => "Задача обновлена",
            'report_data' => "Данные отчета",
            'error' => "Ошибка"
        );
        return $columns;
    }

    public function get_sortable_columns()
    {
        $columns = array(
            'report_id' => array('report_id', true),
            'order_id' => array( 'order_id', false )
        );
        return $columns;
    }

    public function prepare_items()
    {
        $this->_column_headers = array($this->get_columns(), array(), $this->get_sortable_columns());
        $per_page     = $this->get_items_per_page('customers_per_page', 10);
        $current_page = $this->get_pagenum();
        $total_items  = self::record_count();
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page'    => $per_page
        ));
        $this->items = self::get_reports_data($per_page, $current_page);
    }
}

final class InitproKassa_Report {

    const REPORT_TABLE_NAME = 'initprokassa_reports';

    public function create($uniqid, $order_id, $type, $request_check_data, $response_data, $error="")
    {
        global $wpdb;

        $wpdb->insert(
            $wpdb->prefix . self::REPORT_TABLE_NAME,
            array(
                'operation_id' => $uniqid,
                'order_id' => $order_id,
                'operation_type' => $type,
                'request_data' => json_encode($request_check_data),
                'response_data' => $response_data != null ? json_encode($response_data) : null,
                'error' => empty($error) ? null : $error
            ),
            array('%s', '%d', '%s', '%s')
        );
    }

    public function update($uniqid, $state, $report_data)
    {
        global $wpdb;

        $table_name = $wpdb->prefix . self::REPORT_TABLE_NAME;

        $wpdb->update($table_name,
            array(
                'status' => $state,
                'report_data' => json_encode($report_data),
                'error' => $state == "error" ? $report_data['error_description'] : null
            ),
            array('operation_id' => $uniqid),
            array('%s', '%s', '%s'),
            array('%s')
        );
    }
}
