<?php

if (!defined('ABSPATH')) {
    exit;
}

?>

<style>
    select {
        width: 300px;
    }

    input {
        width: 300px;
    }

    .block-header td {
        padding-left: 0px;
        padding-bottom: 0px;
    }

    .block-header p {
        max-width: 860px;
    }

    td.invalid input,
    td.invalid select {
        border-color: #d63638 !important;
        box-shadow: 0 0 2px rgba(214, 54, 56, .8)
    }
</style>

<?php
$calculationSubjects = [
    \Initpro\KassaSdk\CalculationSubject::PRODUCT => 'Товар',
    \Initpro\KassaSdk\CalculationSubject::SERVICE => 'Услуга',
    \Initpro\KassaSdk\CalculationSubject::WORK => 'Работа',
];

$vats = [
    \Initpro\KassaSdk\Vat::RATE_NO => 'Без НДС',
    \Initpro\KassaSdk\Vat::RATE_0 => '0',
    \Initpro\KassaSdk\Vat::RATE_10 => '10%',
    \Initpro\KassaSdk\Vat::RATE_20 => '20%',
    \Initpro\KassaSdk\Vat::RATE_110 => '10/110',
    \Initpro\KassaSdk\Vat::RATE_120 => '20/120'
];

$taxSystems = [
    \Initpro\KassaSdk\TaxSystem::COMMON => 'ОСН',
    \Initpro\KassaSdk\TaxSystem::SIMPLIFIED_IN => 'УСН доход',
    \Initpro\KassaSdk\TaxSystem::SIMPLIFIED_IN_OUT => 'УСН доход - расход',
    \Initpro\KassaSdk\TaxSystem::UTOII => 'ЕНВД',
    \Initpro\KassaSdk\TaxSystem::UST => 'ЕСН',
    \Initpro\KassaSdk\TaxSystem::PATENT => 'Патент',
];

$paymentMethods = WC()->payment_gateways->payment_gateways();

$orderStatuses = ['no' => 'Не выбран'];
foreach (wc_get_order_statuses() as $key => $value) {
    $orderStatuses[str_replace('wc-', '', $key)] = $value;
}

$getOption = function ($key) use ($inputData) {
    $defaultValues = [
        'initprokassa_server_url' => 'https://kassa.initpro.ru',
        'initprokassa_payment_methods' => []
    ];

    if ($inputData[$key]) {
        return $inputData[$key];
    }

    if (get_option($key)) {
        return get_option($key);
    }

    if (isset($defaultValues[$key])) {
        return $defaultValues[$key];
    }

    return false;
}
?>

<h2>Настройки</h2>
<div>
    <?php if (count($inputData) !== 0) : ?>
        <?php if (count($errors) == 0) : ?>
            <div class="updated">
                <p><strong>Ваши настройки сохранены.</strong></p>
            </div>
        <?php else : ?>
            <div class="error">
                <p><strong>При сохранении настроек возникла ошибка. Проверьте указанные данные.</strong></p>
            </div>
        <?php endif; ?>
    <?php endif; ?>

    <form method="post" name="settings_form">
        <table class="form-table">
            <tr>
                <th>
                    <label>API Url:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_server_url']) ? 'invalid' : null; ?>">
                    <input type="text" name="initprokassa_server_url" value="<?php echo $getOption("initprokassa_server_url") ?>" />
                    <?php if (!empty($errors['initprokassa_server_url'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_server_url']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label>Идентификатор магазина:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_shop_id']) ? 'invalid' : null; ?>">
                    <input type="text" name="initprokassa_shop_id" value="<?php echo $getOption("initprokassa_shop_id") ?>" />
                    <?php if (!empty($errors['initprokassa_shop_id'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_shop_id']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label>Секретный ключ:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_secret_key']) ? 'invalid' : null; ?>">
                    <input type="text" name="initprokassa_secret_key" value="<?php echo $getOption("initprokassa_secret_key") ?>" />
                    <?php if (!empty($errors['initprokassa_secret_key'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_secret_key']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label>Идентификатор очереди:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_queue_id']) ? 'invalid' : null; ?>">
                    <input type="text" name="initprokassa_queue_id" value="<?php echo $getOption("initprokassa_queue_id") ?>" />
                    <?php if (!empty($errors['initprokassa_queue_id'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_queue_id']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="vat">НДС на товары:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_vat']) ? 'invalid' : null; ?>">
                    <select name="initprokassa_vat" id="vat">
                        <?php foreach ($vats as $vatValue => $vatName) : ?>
                            <option value="<?php echo esc_attr($vatValue) ?>" <?php echo ($getOption("initprokassa_vat") == $vatValue ? 'selected' : null) ?>>
                                <?php echo esc_html($vatName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_vat'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_vat']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="calculation_subject">Признак предмета расчета(товар):</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_calculation_subject']) ? 'invalid' : null; ?>">
                    <select name="initprokassa_calculation_subject" id="calculation_subject">
                        <?php foreach ($calculationSubjects as $calculationSubjectValue => $calculationSubjectName) : ?>
                            <option value="<?php echo esc_attr($calculationSubjectValue) ?>" <?php echo ($getOption("initprokassa_calculation_subject") == $calculationSubjectValue ? 'selected' : null) ?>>
                                <?php echo esc_html($calculationSubjectName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_calculation_subject'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_calculation_subject']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="vat_delivery">НДС на доставку:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_vat_delivery']) ? 'invalid' : null; ?>">
                    <select name="initprokassa_vat_delivery" id="vat_delivery">
                        <?php foreach ($vats as $vatValue => $vatName) : ?>
                            <option value="<?php echo esc_attr($vatValue) ?>" <?php echo ($getOption("initprokassa_vat_delivery") == $vatValue ? 'selected' : null) ?>>
                                <?php echo esc_html($vatName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_vat_delivery'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_vat_delivery']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="calculation_subject_delivery">Признак предмета расчета(доставка):</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_calculation_subject_delivery']) ? 'invalid' : null; ?>">
                    <select name="initprokassa_calculation_subject_delivery" id="calculation_subject_delivery">
                        <?php foreach ($calculationSubjects as $calculationSubjectValue => $calculationSubjectName) : ?>
                            <option value="<?php echo esc_attr($calculationSubjectValue) ?>" <?php echo ($getOption("initprokassa_calculation_subject_delivery") == $calculationSubjectValue ? 'selected' : null) ?>>
                                <?php echo esc_html($calculationSubjectName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_calculation_subject_delivery'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_calculation_subject_delivery']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="tax_system">Система налогообложения:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_tax_system']) ? 'invalid' : null; ?>">
                    <select name="initprokassa_tax_system" id="tax_system">
                        <?php foreach ($taxSystems as $taxSystemValue => $taxSystemName) : ?>
                            <option value="<?php echo esc_attr($taxSystemValue) ?>" <?php echo ($getOption("initprokassa_tax_system") == $taxSystemValue ? 'selected' : null) ?>>
                                <?php echo esc_html($taxSystemName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_tax_system'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_tax_system']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="payment_method">Способы оплаты, для которых необходимо проводить фискализацию:</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_payment_methods']) ? 'invalid' : null; ?>">
                    <select id="payment_method" name="initprokassa_payment_methods[]" multiple>
                        <?php
                        $savedMethods = is_array($getOption("initprokassa_payment_methods"))
                            ? $getOption("initprokassa_payment_methods")
                            : json_decode($getOption("initprokassa_payment_methods"), true);
                        ?>
                        <?php foreach ($paymentMethods as $method) : ?>
                            <option value="<?php echo esc_attr($method->id) ?>" <?php echo (in_array($method->id, $savedMethods) ? ' selected' : ''); ?>>
                                <?php echo esc_html($method->title) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_payment_methods'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_payment_methods']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>


            <tr class="block-header">
                <td colspan="2">
                    <h2>Формирование двух чеков</h2>
                    <p>Печать чека по предоплате позволяет печатать чек при внесении полной предоплаты до момента передачи товара/услуги клиенту.
                        При реализации сценария печати двух чеков необходимо обязательно заполнить поля "печать чека по предоплате" и "печать чека полного расчета (использование двух чеков)".
                        Второй чек (полного расчета) печатается после фактической передачи товара/услуги клиенту.</p>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="fiscalize_prepayment">Печатать чек по предоплате, при смене статуса заказа на</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_fiscalize_prepayment']) ? 'invalid' : null; ?>">
                    <select id="fiscalize_prepayment" name="initprokassa_fiscalize_prepayment">
                        <?php foreach ($orderStatuses as $orderStatusValue => $orderStatusName) : ?>
                            <option value="<?php echo esc_attr($orderStatusValue) ?>" <?php echo selected($orderStatusValue, $getOption("initprokassa_fiscalize_prepayment"), false) ?>>
                                <?php echo esc_html($orderStatusName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_fiscalize_prepayment'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_fiscalize_prepayment']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="fiscalize_full_payment">Печать чека полного расчета(использование двух чеков), при смене статуса заказа на</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_fiscalize_full_payment']) ? 'invalid' : null; ?>">
                    <select id="fiscalize_full_payment" name="initprokassa_fiscalize_full_payment">
                        <?php foreach ($orderStatuses as $orderStatusValue => $orderStatusName) : ?>
                            <option value="<?php echo esc_attr($orderStatusValue) ?>" <?php echo selected($orderStatusValue, $getOption("initprokassa_fiscalize_full_payment"), false) ?>>
                                <?php echo esc_html($orderStatusName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_fiscalize_full_payment'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_fiscalize_full_payment']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>


            <tr class="block-header">
                <td colspan="2">
                    <h2>Формирование одного чека</h2>
                    <p>Печать чека полного расчета позволяет печатать чек при единовременной оплате и получении товара/услуги клиентом.</p>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="fiscalize_single_receipt_full_payment">Печать чека полного расчета, при смене статуса заказа на</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_fiscalize_single_receipt_full_payment']) ? 'invalid' : null; ?>">
                    <select id="fiscalize_single_receipt_full_payment" name="initprokassa_fiscalize_single_receipt_full_payment">
                        <?php foreach ($orderStatuses as $orderStatusValue => $orderStatusName) : ?>
                            <option value="<?php echo esc_attr($orderStatusValue) ?>" <?php echo selected($orderStatusValue, $getOption("initprokassa_fiscalize_single_receipt_full_payment"), false) ?>>
                                <?php echo esc_html($orderStatusName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_fiscalize_single_receipt_full_payment'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_fiscalize_single_receipt_full_payment']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>


            <tr class="block-header">
                <td colspan="2">
                    <h2>Формирование чека возврата</h2>
                    <p>После того, как заказ перейдет в выбранный ниже статус, будет сформирован чек возврата.</p>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="fiscalize_refund">Печать чека возврата, при смене статуса заказа на</label>
                </th>
                <td class="<?php echo !empty($errors['initprokassa_fiscalize_refund']) ? 'invalid' : null; ?>">
                    <select id="fiscalize_refund" name="initprokassa_fiscalize_refund">
                        <?php foreach ($orderStatuses as $orderStatusValue => $orderStatusName) : ?>
                            <option value="<?php echo esc_attr($orderStatusValue) ?>" <?php echo selected($orderStatusValue, $getOption("initprokassa_fiscalize_refund"), false) ?>>
                                <?php echo esc_html($orderStatusName) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <?php if (!empty($errors['initprokassa_fiscalize_refund'])) : ?>
                        <div class="error-message"><?php echo $errors['initprokassa_fiscalize_refund']; ?></div>
                    <?php endif; ?>
                </td>
            </tr>
        </table>
        <p class="submit">
            <input class="button button-primary" type="submit" value="Cохранить" name="submit">
        </p>
    </form>
</div>
